import { z } from "zod";

export interface CLIFlags {
  help: boolean;
  verbose: boolean;
  stdout: boolean;
}

export interface CLIArguments {
  inputFilePath: string;
  flags: CLIFlags;
}

export const BindingSchema = z.object({
  include: z.array(z.string()).default([]),
  contentKey: z.string().default("content"),
  files: z
    .array(z.string())
    .default(["**/*.yaml", "**/*.md", "**/*.toml", "**/*.json"]),
  options: z.record(z.string(), z.any()).default({}),
  processors: z.array(z.string()).default([]),
});

export interface Binding {
  readonly _raw: z.infer<typeof BindingSchema>;
  readonly bindingPath: string;
  readonly contentKey: string;
  readonly entries: MuseEntry[];
  readonly meta: Record<string, unknown>;
  readonly options: Record<string, unknown>;
  readonly processors: MuseProcessor[];
  readonly imports: Binding[];
}

export type MuseProcessorFn = (
  binding: Binding,
  opts: Record<string, unknown>,
  flags: CLIFlags,
) => Promise<Binding>;

export interface MuseProcessor {
  readonly filePath: string;
  readonly name: string;
  readonly description: string;
  readonly process: MuseProcessorFn;
}

export interface MuseEntry {
  _raw: string;
  filePath: string;
  data: Record<string, unknown>;
  meta: Record<string, unknown>;
}

export type UnknownRecord = Record<string, unknown>;
