import { normalize } from "node:path";

/**
 * Given a file path, ensure it is a file that exists
 * Otherwise, return null
 *
 * @param filePath - The path to the file
 * @returns A promise which resolves to the resolved file path or null
 */
export async function resolveFilePath(
  filePath: string,
): Promise<string | null> {
  const normalized = normalize(filePath);
  const file = Bun.file(normalized);
  const exists = await file.exists();

  if (!exists) {
    return null;
  }

  const stat = await file.stat();
  if (stat.isDirectory()) {
    return null;
  }

  return normalized;
}
